#!/bin/bash

 if [ "$#" -lt  "2" ]
   then
      echo "Too few arguments provided. First argument needs to point to benchmarks."
      echo "Second argument needs to provide output name."
      exit 1
 fi
 
  if [ "$#" -gt  "2" ]
   then
      echo "Too many arguments provided. First argument needs to point to benchmarks."
      echo "Second argument needs to provide output name."
      exit 1
 fi

path=$1
name=$2
msg () {
  echo "run_PAC.sh: $*"
}
msg "path:     $path"
msg "name:     $name"
msg "start:    `date`"

rewr=${name}_rewr.aig
miter=${name}_miter.cnf
mapping=${name}.mapping
spec=${name}.spec
origout=${name}.origout
newout=${name}.newout
equal=${name}.equal
trace=${name}.trace

polys=${name}_no_index.input
pac=${name}_no_index.proof
origspec=${name}_no_index.target

polyst=${name}.input
pact=${name}.proof
origspect=${name}.target


# substitution ----------------------------------------------------------

  amulet/amulet -substitute $path $miter $rewr $mapping $polys $pac $origout $origspec

# picosat ------------------------------------------------------

  picosat $miter -T $trace

# drup2pac ------------------------------------------------------

  drup2pac/drup2pac $miter $trace $polys $pac $equal $mapping


# certify ------------------------------------------------------

  amulet/amulet -certify $rewr $polys $pac $spec $mapping $newout


# matchspec ------------------------------------------------------

  drup2pac/matchspec $origout $newout $equal $spec $pac

# translatePAC ------------------------------------------------------

  translatePAC/translatePAC $polys $pac $polyst $pact
  
  cp $origspec $origspect


rm $miter $rewr $mapping $origout $newout $equal $spec $trace

msg "end:      `date`"
